@@ -53,8 +53,15 @@ namespace KDevelop
 REGISTER_DUCHAIN_ITEM(Declaration);
 
 DeclarationData::DeclarationData()
-  : m_comment(0), m_isDefinition(false), m_inSymbolTable(false), m_isTypeAlias(false),
-    m_anonymousInContext(false), m_isFinal(false), m_alwaysForceDirect(false), m_isAutoDeclaration(false), m_isExplicitlyDeleted(false)
+  : m_comment(0)
+  , m_isDefinition(false)
+  , m_inSymbolTable(false)
+  , m_isTypeAlias(false)
+  , m_anonymousInContext(false)
+  , m_isDeprecated(false)
+  , m_alwaysForceDirect(false)
+  , m_isAutoDeclaration(false)
+  , m_isExplicitlyDeleted(false)
 {
   m_kind = Declaration::Instance;
 }
@@ -70,7 +77,7 @@ m_isDefinition(rhs.m_isDefinition),
 m_inSymbolTable(rhs.m_inSymbolTable),
 m_isTypeAlias(rhs.m_isTypeAlias),
 m_anonymousInContext(rhs.m_anonymousInContext),
-m_isFinal(rhs.m_isFinal),
+m_isDeprecated(rhs.m_isDeprecated),
 m_alwaysForceDirect(rhs.m_alwaysForceDirect),
 m_isAutoDeclaration(rhs.m_isAutoDeclaration),
 m_isExplicitlyDeleted(rhs.m_isExplicitlyDeleted)
@@ -192,7 +199,6 @@ Declaration::~Declaration()
   }
   Q_ASSERT(d_func()->isDynamic() == (!topContext->deleting() || !topContext->isOnDisk() || topContext->m_dynamicData->isTemporaryDeclarationIndex(oldOwnIndex)));
   Q_UNUSED(oldOwnIndex);
-  //DUChain::declarationChanged(this, DUChainObserver::Deletion, DUChainObserver::NotApplicable);
 }
 
 QByteArray Declaration::comment() const {
@@ -252,7 +258,6 @@ void Declaration::setIdentifier(const Identifier& identifier)
   d->m_identifier = identifier;
 
   setInSymbolTable(wasInSymbolTable);
-  //DUChain::declarationChanged(this, DUChainObserver::Change, DUChainObserver::Identifier);
 }
 
 IndexedType Declaration::indexedType() const
@@ -271,14 +276,9 @@ void Declaration::setAbstractType(AbstractType::Ptr type)
   ENSURE_CAN_WRITE
   DUCHAIN_D_DYNAMIC(Declaration);
 
-  //if (d->m_type)
-    //DUChain::declarationChanged(this, DUChainObserver::Removal, DUChainObserver::DataType);
-
   d->m_type = type->indexed();
 
   updateCodeModel();
-  //if (d->m_type)
-    //DUChain::declarationChanged(this, DUChainObserver::Addition, DUChainObserver::DataType);
 }
 
 Declaration* Declaration::specialize(const IndexedInstantiationInformation& /*specialization*/, const TopDUContext* topContext, int /*upDistance*/)
@@ -325,11 +325,6 @@ bool Declaration::isAnonymous() const
 void Declaration::setContext(DUContext* context, bool anonymous)
 {
   Q_ASSERT(!context || context->topContext());
-  ///@todo re-enable. In C++ support we need a short window to put visible declarations into template contexts
-  if(!specialization().index()) {
-    //problem: specialization() doesn't work during destructor
-//     ENSURE_CAN_WRITE
-  }
 
   setInSymbolTable(false);
 
@@ -345,7 +340,6 @@ void Declaration::setContext(DUContext* context, bool anonymous)
   if (m_context) {
     if( !d->m_anonymousInContext ) {
       m_context->m_dynamicData->removeDeclaration(this);
-        //DUChain::declarationChanged(this, DUChainObserver::Removal, DUChainObserver::Context, m_context);
     }
   }
 
@@ -363,7 +357,6 @@ void Declaration::setContext(DUContext* context, bool anonymous)
 
     if(!d->m_anonymousInContext) {
       context->m_dynamicData->addDeclaration(this);
-      //DUChain::declarationChanged(this, DUChainObserver::Addition, DUChainObserver::Context, m_context);
     }
 
     if(context->inSymbolTable() && !anonymous)
@@ -532,14 +525,14 @@ void Declaration::setAutoDeclaration(bool _auto)
   d_func_dynamic()->m_isAutoDeclaration = _auto;
 }
 
-bool Declaration::isFinal() const
+bool Declaration::isDeprecated() const
 {
-  return d_func()->m_isFinal;
+  return d_func()->m_isDeprecated;
 }
 
-void Declaration::setFinal(bool final)
+void Declaration::setDeprecated(bool deprecated)
 {
-  d_func_dynamic()->m_isFinal = final;
+  d_func_dynamic()->m_isDeprecated = deprecated;
 }
 
 bool Declaration::alwaysForceDirect() const
