@@ -16,6 +16,8 @@
 
 //krazy:excludeall=dpointer,inline
 
+#include <config-kdevplatform.h>
+
 #include <QtCore/QMetaType>
 
 #include "../languageexport.h"
@@ -82,6 +84,12 @@ class KDEVPLATFORMLANGUAGE_EXPORT IndexedString {
    */
   explicit IndexedString( const QByteArray& str );
 
+  IndexedString( IndexedString&& o ) Q_DECL_NOEXCEPT
+    : m_index(o.m_index)
+  {
+    o.m_index = 0;
+  }
+
   /**
    * Returns a not reference-counted IndexedString that represents the given index.
    *
@@ -160,6 +168,13 @@ class KDEVPLATFORMLANGUAGE_EXPORT IndexedString {
 
   IndexedString& operator=(const IndexedString&);
 
+  IndexedString& operator=(IndexedString&& o) Q_DECL_NOEXCEPT
+  {
+    m_index = o.m_index;
+    o.m_index = 0;
+    return *this;
+  }
+
   /**
    * Fast index-based comparison
    */
