@@ -245,7 +245,8 @@ void TemplateClassAssistantPrivate::addFilesToTarget (const QHash< QString, KUrl
         {
             if (ProjectFolderItem* folder = item->folder())
             {
-                if (ProjectFileItem* file = project->projectFileManager()->addFile(fileUrl, folder)) {
+                ///FIXME: use Path instead of KUrl in the template class assistant
+                if (ProjectFileItem* file = project->projectFileManager()->addFile(Path(fileUrl), folder)) {
                     fileItems << file;
                     break;
                 }
@@ -417,10 +418,7 @@ void TemplateClassAssistant::next()
     else if (currentPage() == d->classIdentifierPage)
     {
         d->generator->setIdentifier(d->classIdentifierPageWidget->identifier());
-        foreach (const QString& base, d->classIdentifierPageWidget->inheritanceList())
-        {
-            d->generator->addBaseClass(base);
-        }
+        d->generator->setBaseClasses(d->classIdentifierPageWidget->inheritanceList());
     }
     else if (currentPage() == d->overridesPage)
     {
