@@ -16,6 +16,7 @@
 #include "grepviewplugin.h"
 #include "greputil.h"
 
+#include <kglobalsettings.h>
 #include <ktexteditor/cursor.h>
 #include <ktexteditor/document.h>
 #include <klocale.h>
@@ -147,9 +148,9 @@ QVariant GrepOutputItem::data ( int role ) const {
         QString repl  = "<b>" + Qt::escape(grepModel->replacementFor(m_change->m_oldText)) + "</b>";
         QString end   = Qt::escape(text().right(text().length() - m_change->m_range.end.column));
         return QVariant(QString(start + repl + end).trimmed());
-    }
-    else
-    {
+    } else if (role == Qt::FontRole) {
+        return KGlobalSettings::fixedFont();
+    } else {
         return QStandardItem::data(role);
     }
 }
@@ -160,7 +161,7 @@ GrepOutputItem::~GrepOutputItem()
 ///////////////////////////////////////////////////////////////
 
 GrepOutputModel::GrepOutputModel( QObject *parent )
-    : QStandardItemModel( parent ), m_regExp(""), m_replacement(""), m_replacementTemplate(""), m_finalReplacement(""),
+    : QStandardItemModel( parent ), m_regExp(), m_replacement(), m_replacementTemplate(), m_finalReplacement(),
       m_finalUpToDate(false), m_rootItem(0), m_fileCount(0), m_matchCount(0), m_itemsCheckable(false)
 {
     connect(this, SIGNAL(itemChanged(QStandardItem*)),
