@@ -9,8 +9,8 @@
 *                                                                         *
 ***************************************************************************/
 
-#ifndef KDEVKONSOLEVIEW_PART_H
-#define KDEVKONSOLEVIEW_PART_H
+#ifndef KDEVPLATFORM_PLUGIN_KDEVKONSOLEVIEWPLUGIN_H
+#define KDEVPLATFORM_PLUGIN_KDEVKONSOLEVIEWPLUGIN_H
 
 #include <interfaces/iplugin.h>
 #include <QtCore/QVariant>
@@ -24,6 +24,7 @@ class KDevKonsoleViewPlugin : public KDevelop::IPlugin
 public:
     KDevKonsoleViewPlugin( KPluginFactory*, QObject *parent, const QVariantList & = QVariantList() );
     virtual ~KDevKonsoleViewPlugin();
+    virtual void unload();
     KPluginFactory* konsoleFactory() const;
 private:
     class KDevKonsoleViewFactory *m_factory;
