@@ -16,16 +16,15 @@
 
 #include <QObject>
 #include <QPointer>
-#include <memory>
-#include <qstandarditemmodel.h>
-#include <interfaces/iplugin.h>
-#include "localpatchsource.h"
-#include "ui_patchreview.h"
-#include <language/duchain/indexedstring.h>
-#include "libdiff2/diffmodel.h"
 
+#include <interfaces/iplugin.h>
+#include <interfaces/ipatchsource.h>
 
 class PatchHighlighter;
+class PatchReviewToolViewFactory;
+
+class QTimer;
+
 namespace KDevelop {
 class IDocument;
 }
@@ -33,8 +32,6 @@ namespace Sublime {
 class Area;
 }
 
-class PatchReviewToolViewFactory;
-
 namespace Diff2
 {
 class KompareModelList;
@@ -54,7 +51,7 @@ class PatchReviewPlugin : public KDevelop::IPlugin, public KDevelop::IPatchRevie
     Q_INTERFACES( KDevelop::IPatchReview )
 
 public :
-        PatchReviewPlugin( QObject *parent, const QVariantList & = QVariantList() );
+    PatchReviewPlugin( QObject *parent, const QVariantList & = QVariantList() );
     ~PatchReviewPlugin();
     virtual void unload();
 
@@ -64,25 +61,20 @@ public :
         return m_patch;
     }
 
-    QList< KDevelop::IPatchSource::Ptr > knownPatches() const {
-        return m_knownPatches;
-    }
-
     Diff2::KompareModelList* modelList() const {
-        return m_modelList.get();
+        return m_modelList.data();
     }
 
     void seekHunk( bool forwards, const KUrl& file = KUrl() );
 
     void setPatch( KDevelop::IPatchSource* patch );
 
-    void registerPatch( KDevelop::IPatchSource::Ptr patch );
-
     virtual void startReview( KDevelop::IPatchSource* patch, ReviewMode mode );
 
     void finishReview( QList< KUrl > selection );
 
     KUrl urlForFileModel( const Diff2::DiffModel* model );
+    QAction* finishReviewAction() const { return m_finishReview; }
 
 Q_SIGNALS:
     void startingNewReview();
@@ -118,8 +110,6 @@ private:
     // Returns false on failure (if the user disagreed).
     bool setUniqueEmptyWorkingSet();
 
-    QList< KDevelop::IPatchSource::Ptr > m_knownPatches;
-
     void addHighlighting( const KUrl& file, KDevelop::IDocument* document = 0 );
     void removeHighlighting( const KUrl& file = KUrl() );
 
@@ -128,14 +118,15 @@ private:
     QTimer* m_updateKompareTimer;
 
     PatchReviewToolViewFactory* m_factory;
+    QAction* m_finishReview;
 
     #if 0
     void determineState();
     #endif
 
     QPointer< DiffSettings > m_diffSettings;
-    std::auto_ptr< Kompare::Info > m_kompareInfo;
-    std::auto_ptr< Diff2::KompareModelList > m_modelList;
+    QScopedPointer< Kompare::Info > m_kompareInfo;
+    QScopedPointer< Diff2::KompareModelList > m_modelList;
     typedef QMap< KUrl, QPointer< PatchHighlighter > > HighlightMap;
     HighlightMap m_highlighters;
 };
