@@ -41,6 +41,33 @@
 
 using namespace KDevelop;
 
+namespace {
+
+QSet<IndexedString> openFiles()
+{
+    QSet<IndexedString> openFiles;
+    const QList<IDocument*>& docs = ICore::self()->documentController()->openDocuments();
+    openFiles.reserve(docs.size());
+    foreach( IDocument* doc, docs ) {
+        openFiles << IndexedString(doc->url().pathOrUrl());
+    }
+    return openFiles;
+}
+
+QString iconNameForUrl(const IndexedString& url)
+{
+    if (url.isEmpty()) {
+        return QString("tab-duplicate");
+    }
+    ProjectBaseItem* item = ICore::self()->projectController()->projectModel()->itemForPath(url);
+    if (item) {
+        return item->iconName();
+    }
+    return QString("unknown");
+}
+
+}
+
 ProjectFileData::ProjectFileData( const ProjectFile& file )
 : m_file(file)
 {
@@ -48,22 +75,17 @@ ProjectFileData::ProjectFileData( const ProjectFile& file )
 
 QString ProjectFileData::text() const
 {
-    KUrl u(m_file.projectUrl);
-    QString ret = KUrl::relativePath( u.pathOrUrl(), m_file.pathOrUrl );
-    if (ret.startsWith(QLatin1String("./"))) {
-        ret.remove(0, 2);
-    }
-    return ret;
+    return m_file.projectPath.relativePath(m_file.path);
 }
 
 QString ProjectFileData::htmlDescription() const
 {
-  return "<small><small>" + i18nc("%1: project name", "Project %1", m_file.project)  + "</small></small>";
+  return "<small><small>" + i18nc("%1: project name", "Project %1", project())  + "</small></small>";
 }
 
 bool ProjectFileData::execute( QString& filterText )
 {
-    const KUrl url(m_file.pathOrUrl);
+    const KUrl url = m_file.path.toUrl();
     IOpenWith::openFiles(KUrl::List() << url);
     QString path;
     uint lineNumber;
@@ -91,7 +113,7 @@ QList<QVariant> ProjectFileData::highlighting() const
 
     QList<QVariant> ret;
 
-    int fileNameLength = KUrl(m_file.pathOrUrl).fileName().length();
+    int fileNameLength = m_file.path.lastPathSegment().length();
 
     ret << 0;
     ret << txt.length() - fileNameLength;
@@ -105,7 +127,7 @@ QList<QVariant> ProjectFileData::highlighting() const
 
 QWidget* ProjectFileData::expandingWidget() const
 {
-    const KUrl url(m_file.pathOrUrl);
+    const KUrl url = m_file.path.toUrl();
     DUChainReadLocker lock;
 
     ///Find a du-chain for the document
@@ -122,14 +144,14 @@ QWidget* ProjectFileData::expandingWidget() const
     if( chosen ) {
         return chosen->createNavigationWidget(0, 0,
             "<small><small>"
-            + i18nc("%1: project name", "Project %1", m_file.project)
+            + i18nc("%1: project name", "Project %1", project())
             + "</small></small>");
     } else {
         QTextBrowser* ret = new QTextBrowser();
         ret->resize(400, 100);
         ret->setText(
                 "<small><small>"
-                + i18nc("%1: project name", "Project %1", m_file.project)
+                + i18nc("%1: project name", "Project %1", project())
                 + "<br>" + i18n("Not parsed yet") + "</small></small>");
         return ret;
     }
@@ -137,21 +159,9 @@ QWidget* ProjectFileData::expandingWidget() const
     return 0;
 }
 
-static QString iconNameForUrl(const IndexedString& url)
-{
-    if (url.isEmpty()) {
-        return QString("tab-duplicate");
-    }
-    ProjectBaseItem* item = ICore::self()->projectController()->projectModel()->itemForUrl(url);
-    if (item) {
-        return item->iconName();
-    }
-    return QString("unknown");
-}
-
 QIcon ProjectFileData::icon() const
 {
-    const QString& iconName = iconNameForUrl(m_file.indexedUrl);
+    const QString& iconName = iconNameForUrl(m_file.indexedPath);
 
     /**
      * FIXME: Move this cache into a more central place and reuse it elsewhere.
@@ -171,6 +181,16 @@ QIcon ProjectFileData::icon() const
     return pixmap;
 }
 
+QString ProjectFileData::project() const
+{
+    const IProject* project = ICore::self()->projectController()->findProjectForUrl(m_file.path.toUrl());
+    if (project) {
+        return project->name();
+    } else {
+        return i18n("none");
+    }
+}
+
 BaseFileDataProvider::BaseFileDataProvider()
 {
 }
@@ -191,27 +211,22 @@ void BaseFileDataProvider::setFilterText( const QString& text )
             path = url.pathOrUrl();
         }
     }
-    Base::setFilter( path.split('/', QString::SkipEmptyParts), QChar('/') );
+    setFilter( path.split('/', QString::SkipEmptyParts) );
 }
 
 uint BaseFileDataProvider::itemCount() const
 {
-    return Base::filteredItems().count();
+    return filteredItems().count();
 }
 
 uint BaseFileDataProvider::unfilteredItemCount() const
 {
-    return Base::items().count();
+    return items().count();
 }
 
 QuickOpenDataPointer BaseFileDataProvider::data(uint row) const
 {
-    return QuickOpenDataPointer(new ProjectFileData( Base::filteredItems().at(row) ));
-}
-
-QString BaseFileDataProvider::itemText( const ProjectFile& data ) const
-{
-    return data.pathOrUrl;
+    return QuickOpenDataPointer(new ProjectFileData( filteredItems().at(row) ));
 }
 
 ProjectFileDataProvider::ProjectFileDataProvider()
@@ -224,8 +239,8 @@ ProjectFileDataProvider::ProjectFileDataProvider()
 
 void ProjectFileDataProvider::projectClosing( IProject* project )
 {
-    foreach(const IndexedString& str, project->fileSet()) {
-        fileRemovedFromSet(project, str);
+    foreach(ProjectFileItem* file, project->files()) {
+        fileRemovedFromSet(file);
     }
 }
 
@@ -233,8 +248,8 @@ void ProjectFileDataProvider::projectOpened( IProject* project )
 {
     const int processAfter = 1000;
     int processed = 0;
-    foreach(const IndexedString& url, project->fileSet()) {
-        fileAddedToSet(project, url);
+    foreach(ProjectFileItem* file, project->files()) {
+        fileAddedToSet(file);
         if (++processed == processAfter) {
             // prevent UI-lockup when a huge project was imported
             QApplication::processEvents();
@@ -242,74 +257,62 @@ void ProjectFileDataProvider::projectOpened( IProject* project )
         }
     }
 
-    connect(project, SIGNAL(fileAddedToSet(KDevelop::IProject*, KDevelop::IndexedString)),
-            this, SLOT(fileAddedToSet(KDevelop::IProject*, KDevelop::IndexedString)));
-    connect(project, SIGNAL(fileRemovedFromSet(KDevelop::IProject*, KDevelop::IndexedString)),
-            this, SLOT(fileRemovedFromSet(KDevelop::IProject*, KDevelop::IndexedString)));
+    connect(project, SIGNAL(fileAddedToSet(KDevelop::ProjectFileItem*)),
+            this, SLOT(fileAddedToSet(KDevelop::ProjectFileItem*)));
+    connect(project, SIGNAL(fileRemovedFromSet(KDevelop::ProjectFileItem*)),
+            this, SLOT(fileRemovedFromSet(KDevelop::ProjectFileItem*)));
 }
 
-void ProjectFileDataProvider::fileAddedToSet( IProject* project, const IndexedString& url )
+void ProjectFileDataProvider::fileAddedToSet( ProjectFileItem* file )
 {
     ProjectFile f;
-    f.project = project->name();
-    f.projectUrl = project->folder();
-    f.pathOrUrl = url.str();
-    f.indexedUrl = url;
-    m_projectFiles.insert(f.pathOrUrl, f);
-}
-
-void ProjectFileDataProvider::fileRemovedFromSet( IProject*, const IndexedString& url )
-{
-    m_projectFiles.remove(url.str());
-}
-
-namespace
-{
-QSet<IndexedString> openFiles()
-{
-    QSet<IndexedString> openFiles;
-    const QList<IDocument*>& docs = ICore::self()->documentController()->openDocuments();
-    openFiles.reserve(docs.size());
-    foreach( IDocument* doc, docs ) {
-        openFiles << IndexedString(doc->url().pathOrUrl());
+    f.projectPath = file->project()->path();
+    f.path = file->path();
+    f.indexedPath = file->indexedPath();
+    f.outsideOfProject = !f.projectPath.isParentOf(f.path);
+    QList<ProjectFile>::iterator it = qLowerBound(m_projectFiles.begin(), m_projectFiles.end(), f);
+    if (it == m_projectFiles.end() || it->path != f.path) {
+        m_projectFiles.insert(it, f);
     }
-    return openFiles;
 }
 
-QSet<QString> openFilesPathsOrUrls()
+void ProjectFileDataProvider::fileRemovedFromSet( ProjectFileItem* file )
 {
-    QSet<QString> openFiles;
-    const QList<IDocument*>& docs = ICore::self()->documentController()->openDocuments();
-    openFiles.reserve(docs.size());
-    foreach( IDocument* doc, docs ) {
-        openFiles << doc->url().pathOrUrl();
-    }
-    return openFiles;
-}
+    ProjectFile item;
+    item.path = file->path();
 
-bool sortProjectFiles(const ProjectFile& left, const ProjectFile& right)
-{
-    // arbitrarily sort projects (fast)
-    if ( left.project != right.project ) {
-        return left.project < right.project;
+    // fast-path for non-generated files
+    // NOTE: figuring out whether something is generated is expensive... and since
+    // generated files are rare we apply this two-step algorithm here
+    QList<ProjectFile>::iterator it = qBinaryFind(m_projectFiles.begin(), m_projectFiles.end(), item);
+    if (it != m_projectFiles.end()) {
+        m_projectFiles.erase(it);
+        return;
+    }
+
+    // last try: maybe it was generated
+    item.outsideOfProject = true;
+    it = qBinaryFind(m_projectFiles.begin(), m_projectFiles.end(), item);
+    if (it != m_projectFiles.end()) {
+        m_projectFiles.erase(it);
+        return;
     }
-    return left.pathOrUrl < right.pathOrUrl;
-}
 }
 
 void ProjectFileDataProvider::reset()
 {
-    Base::clearFilter();
+    clearFilter();
 
-    QSet<QString> openFiles = openFilesPathsOrUrls();
-    QList<ProjectFile> projectFiles;
-    projectFiles.reserve(m_projectFiles.size());
+    QList<ProjectFile> projectFiles = m_projectFiles;
 
-    for(QMap<QString, ProjectFile>::const_iterator it = m_projectFiles.constBegin();
-        it != m_projectFiles.constEnd(); ++it)
+    const auto& open = openFiles();
+    for(QList<ProjectFile>::iterator it = projectFiles.begin();
+        it != projectFiles.end();)
     {
-        if (!openFiles.contains(it.key())) {
-            projectFiles << *it;
+        if (open.contains(it->indexedPath)) {
+            it = projectFiles.erase(it);
+        } else {
+            ++it;
         }
     }
 
@@ -328,7 +331,7 @@ QSet<IndexedString> ProjectFileDataProvider::files() const
 
 void OpenFilesDataProvider::reset()
 {
-    Base::clearFilter();
+    clearFilter();
     IProjectController* projCtrl = ICore::self()->projectController();
     IDocumentController* docCtrl = ICore::self()->documentController();
     const QList<IDocument*>& docs = docCtrl->openDocuments();
@@ -337,18 +340,15 @@ void OpenFilesDataProvider::reset()
     currentFiles.reserve(docs.size());
     foreach( IDocument* doc, docs ) {
         ProjectFile f;
-        f.pathOrUrl = doc->url().pathOrUrl();
+        f.path = Path(doc->url());
         IProject* project = projCtrl->findProjectForUrl(doc->url());
         if (project) {
-            f.projectUrl = project->folder();
-            f.project = project->name();
-        } else {
-            f.project = i18n("none");
+            f.projectPath = project->path();
         }
         currentFiles << f;
     }
 
-    qSort(currentFiles.begin(), currentFiles.end(), sortProjectFiles);
+    qSort(currentFiles);
 
     setItems(currentFiles);
 }
