@@ -65,7 +65,6 @@
 #include "projectfilequickopen.h"
 #include "projectitemquickopen.h"
 #include "declarationlistquickopen.h"
-#include "customlistquickopen.h"
 #include "documentationquickopenprovider.h"
 #include <language/duchain/functiondefinition.h>
 #include <qmenu.h>
@@ -78,8 +77,6 @@
 
 using namespace KDevelop;
 
-const int rowCountForDisablingScrollBar = 5000;
-
 const bool noHtmlDestriptionInOutline = true;
 
 class QuickOpenWidgetCreator {
@@ -416,10 +413,12 @@ void QuickOpenWidget::prepareShow()
     o.searchLine->selectAll();
   }
   
-  applyFilter();
+  m_model->restart(false);
   
-  connect( o.list->selectionModel(), SIGNAL(currentRowChanged(QModelIndex,QModelIndex)), this, SLOT(currentChanged(QModelIndex,QModelIndex)) );
-  connect( o.list->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(currentChanged(QItemSelection,QItemSelection)) );
+  connect( o.list->selectionModel(), SIGNAL(currentRowChanged(QModelIndex,QModelIndex)),
+           SLOT(callRowSelected()) );
+  connect( o.list->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+           SLOT(callRowSelected()) );
 }
 
 void QuickOpenWidgetDialog::run() {
@@ -530,14 +529,6 @@ void QuickOpenWidget::callRowSelected() {
     kDebug() << "current index is not valid";
 }
 
-void QuickOpenWidget::currentChanged( const QModelIndex& /*current*/, const QModelIndex& /*previous */) {
-  callRowSelected();
-}
-
-void QuickOpenWidget::currentChanged( const QItemSelection& /*current*/, const QItemSelection& /*previous */) {
-  callRowSelected();
-}
-
 void QuickOpenWidget::accept() {
   QString filterText = o.searchLine->text();
   m_model->execute( o.list->currentIndex(), filterText );
@@ -763,6 +754,11 @@ void QuickOpenPlugin::createActionsForMainWindow(Sublime::MainWindow* /*window*/
     quickOpenFunction->setShortcut( Qt::CTRL | Qt::ALT | Qt::Key_M );
     connect(quickOpenFunction, SIGNAL(triggered(bool)), this, SLOT(quickOpenFunction()));
 
+    KAction* quickOpenAlreadyOpen = actions.addAction("quick_open_already_open");
+    quickOpenAlreadyOpen->setText( i18n("Quick Open &Already Open File") );
+    quickOpenAlreadyOpen->setIcon( KIcon("quickopen-file") );
+    connect(quickOpenAlreadyOpen, SIGNAL(triggered(bool)), this, SLOT(quickOpenOpenFile()));
+
     KAction* quickOpenDocumentation = actions.addAction("quick_open_documentation");
     quickOpenDocumentation->setText( i18n("Quick Open &Documentation") );
     quickOpenDocumentation->setIcon( KIcon("quickopen-documentation") );
@@ -786,10 +782,6 @@ void QuickOpenPlugin::createActionsForMainWindow(Sublime::MainWindow* /*window*/
 //     quickOpenLine->setShortcut( Qt::CTRL | Qt::ALT | Qt::Key_E );
 //     connect(quickOpenLine, SIGNAL(triggered(bool)), this, SLOT(quickOpenLine(bool)));
     quickOpenLine->setDefaultWidget(createQuickOpenLineWidget());
-//     KAction* quickOpenNavigate = actions.addAction("quick_open_navigate");
-//     quickOpenNavigate->setText( i18n("Navigate Declaration") );
-//     quickOpenNavigate->setShortcut( Qt::ALT | Qt::Key_Space );
-//     connect(quickOpenNavigate, SIGNAL(triggered(bool)), this, SLOT(quickOpenNavigate()));
 
     KAction* quickOpenNextFunction = actions.addAction("quick_open_next_function");
     quickOpenNextFunction->setText( i18n("Next Function") );
@@ -920,7 +912,9 @@ void QuickOpenPlugin::showQuickOpen( ModelTypes modes )
   if( modes & Classes )
     initialItems << i18n("Classes");
   
-  QStringList useScopes = lastUsedScopes;
+  QStringList useScopes;
+  if ( modes != OpenFiles )
+    useScopes = lastUsedScopes;
   
   if((modes & OpenFiles) && !useScopes.contains(i18n("Currently Open")))
     useScopes << i18n("Currently Open");
@@ -993,6 +987,11 @@ void QuickOpenPlugin::quickOpenClass()
   showQuickOpen( Classes );
 }
 
+void QuickOpenPlugin::quickOpenOpenFile()
+{
+  showQuickOpen( OpenFiles );
+}
+
 void QuickOpenPlugin::quickOpenDocumentation()
 {
   showQuickOpenWidget(QStringList(i18n("Documentation")), QStringList(i18n("Includes")), true);
@@ -1133,60 +1132,6 @@ void QuickOpenPlugin::quickOpenDefinition()
   core()->documentController()->openDocument(KUrl(u.str()), c.textCursor());
 }
 
-
-void QuickOpenPlugin::quickOpenNavigate()
-{
-  if(!freeModel())
-    return;
-  KDevelop::DUChainReadLocker lock( DUChain::lock() );
-
-  QWidget* widget = specialObjectNavigationWidget();
-  Declaration* decl = cursorDeclaration();
-
-  if(widget || decl) {
-
-    QuickOpenModel* model = new QuickOpenModel(0);
-    model->setExpandingWidgetHeightIncrease(200); //Make the widget higher, since it's the only visible item
-
-    if(widget) {
-      QPair<KUrl, SimpleCursor> jumpPos = specialObjectJumpPosition();
-
-      CustomItem item;
-      item.m_widget = widget;
-      item.m_executeTargetPosition = jumpPos.second;
-      item.m_executeTargetUrl = jumpPos.first;
-
-      QList<CustomItem> items;
-      items << item;
-
-      model->registerProvider( QStringList(), QStringList(), new CustomItemDataProvider(items) );
-    }else{
-      DUChainItem item;
-
-      item.m_item = IndexedDeclaration(decl);
-      item.m_text = decl->qualifiedIdentifier().toString();
-
-      QList<DUChainItem> items;
-      items << item;
-
-      model->registerProvider( QStringList(), QStringList(), new DeclarationListDataProvider(this, items) );
-    }
-
-    //Change the parent so there are no conflicts in destruction order
-    QuickOpenWidgetDialog* dialog = new QuickOpenWidgetDialog( i18n("Navigate"), model, QStringList(), QStringList(), true, true );
-    m_currentWidgetHandler = dialog;
-    model->setParent(m_currentWidgetHandler);
-    model->setExpanded(model->index(0,0, QModelIndex()), true);
-
-    dialog->run();
-  }
-
-  if(!decl) {
-    kDebug() << "Found no declaration for cursor, cannot navigate";
-    return;
-  }
-}
-
 bool QuickOpenPlugin::freeModel()
 {
   if(m_currentWidgetHandler)
