@@ -51,6 +51,7 @@ Boston, MA 02110-1301, USA.
 #include <interfaces/context.h>
 #include <interfaces/ilanguagecontroller.h>
 #include <project/projectmodel.h>
+#include <util/path.h>
 
 #include "core.h"
 #include "mainwindow.h"
@@ -64,14 +65,10 @@ Boston, MA 02110-1301, USA.
 #include <vcs/interfaces/ibasicversioncontrol.h>
 #include <vcs/models/vcsannotationmodel.h>
 #include <vcs/vcsjob.h>
+#include <vcs/vcspluginhelper.h>
 
-#include <config-kdevplatform.h>
 #include <language/backgroundparser/backgroundparser.h>
 
-#ifdef HAVE_KOMPARE
-    #include "patchdocument.h"
-#endif
-
 #define EMPTY_DOCUMENT_URL i18n("Untitled")
 
 namespace KDevelop
@@ -260,6 +257,10 @@ struct DocumentControllerPrivate {
             }
             else if (!KIO::NetAccess::exists( url, KIO::NetAccess::SourceSide, ICore::self()->uiController()->activeMainWindow() ))
             {
+                //Don't create a new file if we are not in the code mode.
+                if (static_cast<KDevelop::MainWindow*>(ICore::self()->uiController()->activeMainWindow())->area()->objectName() != "code") {
+                    return 0;
+                }
                 // enfore text mime type in order to create a kate part editor which then can be used to create the file
                 // otherwise we could end up opening e.g. okteta which then crashes, see: https://bugs.kde.org/id=326434
                 mimeType = KMimeType::mimeType("text/plain");
@@ -289,14 +290,9 @@ struct DocumentControllerPrivate {
             if( prefName.isEmpty() )
             {
                 // Try to find a plugin that handles this mimetype
-                QString constraint = QString("'%1' in [X-KDevelop-SupportedMimeTypes]").arg(mimeType->name());
-                KPluginInfo::List plugins = IPluginController::queryPlugins( constraint );
-
-                if( !plugins.isEmpty() )
-                {
-                    KPluginInfo info = plugins.first();
-                    Core::self()->pluginController()->loadPlugin( info.pluginName() );
-                }
+                QVariantMap constraints;
+                constraints.insert("X-KDevelop-SupportedMimeTypes", mimeType->name());
+                Core::self()->pluginController()->pluginForExtension(QString(), QString(), constraints);
             }
             
             if( factories.contains( mimeType->name() ) )
@@ -586,10 +582,6 @@ DocumentController::DocumentController( QObject *parent )
     connect(this, SIGNAL(documentUrlChanged(KDevelop::IDocument*)), this, SLOT(changeDocumentUrl(KDevelop::IDocument*)));
 
     if(!(Core::self()->setupFlags() & Core::NoUi)) setupActions();
-
-#ifdef HAVE_KOMPARE
-    registerDocumentForMimetype("text/x-patch", new PatchDocumentFactory);
-#endif
 }
 
 void DocumentController::initialize()
@@ -986,7 +978,7 @@ QString DocumentController::activeDocumentPath( QString target ) const
         Context* selection = ICore::self()->selectionController()->currentSelection();
         if(selection && selection->type() == Context::ProjectItemContext && static_cast<ProjectItemContext*>(selection)->items().size())
         {
-            QString ret = static_cast<ProjectItemContext*>(selection)->items()[0]->url().pathOrUrl();
+            QString ret = static_cast<ProjectItemContext*>(selection)->items()[0]->path().pathOrUrl();
             if(static_cast<ProjectItemContext*>(selection)->items()[0]->folder())
                 ret += "/.";
             return  ret;
@@ -1221,36 +1213,20 @@ void DocumentController::vcsAnnotateCurrentDocument()
     IDocument* doc = activeDocument();
     KUrl url = doc->url();
     IProject* project = KDevelop::ICore::self()->projectController()->findProjectForUrl(url);
-    IBasicVersionControl* iface = 0;
     if(project && project->versionControlPlugin()) {
+        IBasicVersionControl* iface = 0;
         iface = project->versionControlPlugin()->extension<IBasicVersionControl>();
+        auto helper = new VcsPluginHelper(project->versionControlPlugin(), iface);
+        connect(doc->textDocument(), SIGNAL(aboutToClose(KTextEditor::Document*)),
+                helper, SLOT(disposeEventually(KTextEditor::Document*)));
+        connect(doc->textDocument()->activeView(), SIGNAL(annotationBorderVisibilityChanged(View*,bool)),
+                helper, SLOT(disposeEventually(View*, bool)));
+        helper->addContextDocument(url);
+        helper->annotation();
     }
-
-    if (iface && doc && doc->textDocument() && iface->isVersionControlled(url)) {
-        KTextEditor::AnnotationViewInterface* viewiface = qobject_cast<KTextEditor::AnnotationViewInterface*>(doc->textDocument()->activeView());
-        if(viewiface && viewiface->isAnnotationBorderVisible()) {
-            viewiface->setAnnotationBorderVisible(false);
-            return;
-        }
-        KDevelop::VcsJob* job = iface->annotate(url);
-        if( !job )
-        {
-            kWarning() << "Couldn't create annotate job for:" << url << "with iface:" << iface << dynamic_cast<KDevelop::IPlugin*>( iface );
-            return;
-        }
-        KTextEditor::AnnotationInterface* annotateiface = qobject_cast<KTextEditor::AnnotationInterface*>(doc->textDocument());
-
-        if (annotateiface && viewiface) {
-            KDevelop::VcsAnnotationModel* model = new KDevelop::VcsAnnotationModel(job, url, doc->textDocument());
-            annotateiface->setAnnotationModel(model);
-            viewiface->setAnnotationBorderVisible(true);
-        } else {
-            KMessageBox::error(0, i18n("Cannot display annotations, missing interface KTextEditor::AnnotationInterface for the editor."));
-            delete job;
-        }
-    } else {
-        KMessageBox::error(0, i18n("Cannot execute annotate action because the "
-                                   "document was not found, it was not versioned or it was not a text document:\n%1", url.pathOrUrl()));
+    else {
+        KMessageBox::error(0, i18n("Could not annotate the document because it is not "
+                                   "part of a version-controlled project."));
     }
 }
 
