@@ -26,7 +26,10 @@ Boston, MA 02110-1301, USA.
 
 #include "shellexport.h"
 
-class QModelIndex;
+namespace Sublime {
+    class Area;
+}
+
 namespace KIO {
     class Job;
 }
@@ -36,7 +39,6 @@ namespace KDevelop
 
 class IProject;
 class Core;
-class UiController;
 class Context;
 class ContextMenuExtension;
 class IPlugin;
@@ -88,8 +90,8 @@ public:
     void setDialogProvider(IProjectDialogProvider*);
 
     KUrl projectsBaseDirectory() const;
-    QString prettyFileName(KUrl url, FormattingOptions format = FormatHtml) const;
-    QString prettyFilePath(KUrl url, FormattingOptions format = FormatHtml) const;
+    QString prettyFileName(const KUrl& url, FormattingOptions format = FormatHtml) const override;
+    QString prettyFilePath(const KUrl& url, FormattingOptions format = FormatHtml) const override;
 
     ContextMenuExtension contextMenuExtension( KDevelop::Context* ctx );
 
@@ -101,6 +103,9 @@ public Q_SLOTS:
     void projectImportingFinished( IProject* );
     virtual void closeProject( IProject* );
     virtual void configureProject( IProject* );
+
+    virtual void reparseProject( IProject* project, bool forceUpdate = false  ) override;
+
     void eventuallyOpenProjectFile(KIO::Job*,KIO::UDSEntryList);
     void openProjectForUrlSlot(bool);
 //     void changeCurrentProject( ProjectBaseItem* );
@@ -138,6 +143,7 @@ private:
     Q_PRIVATE_SLOT(d, void updateActionStates( KDevelop::Context* ) )
     Q_PRIVATE_SLOT(d, void closeSelectedProjects() )
     Q_PRIVATE_SLOT(d, void openProjectConfig() )
+    Q_PRIVATE_SLOT(d, void areaChanged(Sublime::Area*) )
     class ProjectControllerPrivate* const d;
     friend class ProjectControllerPrivate;
 };
