@@ -66,30 +66,11 @@ CCPreferences::CCPreferences( QWidget *parent, const QVariantList &args )
     load();
 }
 
-void CCPreferences::load()
-{
-    KCModule::load();
-    writeToSettings();
-}
-
-void CCPreferences::writeToSettings()
+void CCPreferences::notifySettingsChanged()
 {
     CompletionSettings& settings(static_cast<CompletionSettings&>(*ICore::self()->languageController()->completionSettings()));
-    settings.m_automatic = preferencesDialog->kcfg_automaticInvocation->isChecked();
-    if(preferencesDialog->kcfg_alwaysFullCompletion->isChecked())
-        settings.m_level = ICompletionSettings::AlwaysFull;
-    if(preferencesDialog->kcfg_minimalAutomaticCompletion->isChecked())
-        settings.m_level = ICompletionSettings::MinimalWhenAutomatic;
-    if(preferencesDialog->kcfg_alwaysMinimalCompletion->isChecked())
-        settings.m_level = ICompletionSettings::Minimal;
-    
-    settings.m_localColorizationLevel = preferencesDialog->kcfg_localColorization->value();
-    settings.m_globalColorizationLevel = preferencesDialog->kcfg_globalColorization->value();
-    settings.m_highlightSemanticProblems = preferencesDialog->kcfg_highlightSemanticProblems->isChecked();
-    settings.m_showMultiLineInformation = preferencesDialog->kcfg_showMultiLineSelectionInformation->isChecked();
-    settings.m_minFilesForSimplifiedParsing = preferencesDialog->kcfg_minFilesForSimplifiedParsing->value();
-    
-    emit settings.emitChanged();
+
+    settings.emitChanged();
 }
 
 CCPreferences::~CCPreferences( )
@@ -106,8 +87,8 @@ void CCPreferences::save()
             foreach (View* view, textDoc->views())
                 if (CodeCompletionInterface* cc = dynamic_cast<CodeCompletionInterface*>(view))
                     cc->setAutomaticInvocationEnabled(preferencesDialog->kcfg_automaticInvocation->isChecked());
-    
-    writeToSettings();
+
+    notifySettingsChanged();
 }
 
 }
